@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2021, Lawrence Livermore National Security, LLC and
+// Copyright (c) 2017-2025, Lawrence Livermore National Security, LLC and
 // other BLT Project Developers. See the top-level LICENSE file for details
 //
 // SPDX-License-Identifier: (BSD-3-Clause)
@@ -8,20 +8,31 @@
 // file: blt_hip_runtime_smoke.cpp
 //
 //-----------------------------------------------------------------------------
-
-#include <iostream>
+#include <cstdio>
 #include "hip/hip_runtime_api.h"
-#include <stdio.h>
 
 int main()
 {
-  int nDevices;
+  hipError_t rc = hipSuccess; 
+  int nDevices{0};
+
+  rc = hipGetDeviceCount(&nDevices);
+  if (rc != hipSuccess)
+  {
+    fprintf(stderr, "[HIP ERROR]: %s", hipGetErrorString(rc));
+    return -1;
+  }
 
-  hipGetDeviceCount(&nDevices);
   for (int i = 0; i < nDevices; i++)
   {
     hipDeviceProp_t prop;
-    hipGetDeviceProperties(&prop, i);
+    rc = hipGetDeviceProperties(&prop, i);
+    if (rc != hipSuccess)
+    {
+      fprintf(stderr, "[HIP ERROR]: %s", hipGetErrorString(rc));
+      return -1;
+    }
+
     printf("Device Number: %d\n", i);
     printf("  Device name: %s\n", prop.name);
     printf("  Memory Clock Rate (KHz): %d\n",
