@@ -9,8 +9,8 @@
  */
 
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
-// Copyright (c) 2016-21, Lawrence Livermore National Security, LLC
-// and RAJA project contributors. See the RAJA/COPYRIGHT file for details.
+// Copyright (c) 2016-25, Lawrence Livermore National Security, LLC
+// and RAJA project contributors. See the RAJA/LICENSE file for details.
 //
 // SPDX-License-Identifier: (BSD-3-Clause)
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
@@ -34,10 +34,19 @@
 namespace RAJA
 {
 
-enum PushEnd { PUSH_FRONT, PUSH_BACK };
-enum PushCopy { PUSH_COPY, PUSH_NOCOPY };
+enum PushEnd
+{
+  PUSH_FRONT,
+  PUSH_BACK
+};
 
-template <typename... TALL>
+enum PushCopy
+{
+  PUSH_COPY,
+  PUSH_NOCOPY
+};
+
+template<typename... TALL>
 class TypedIndexSet;
 
 namespace policy
@@ -52,11 +61,12 @@ namespace indexset
 /// over segments.  The second describes the policy for executing
 /// each segment.
 ///
-template <typename SEG_ITER_POLICY_T, typename SEG_EXEC_POLICY_T = void>
+template<typename SEG_ITER_POLICY_T, typename SEG_EXEC_POLICY_T = void>
 struct ExecPolicy
     : public RAJA::make_policy_pattern_t<SEG_EXEC_POLICY_T::policy,
-                                         RAJA::Pattern::forall> {
-  using seg_it = SEG_ITER_POLICY_T;
+                                         RAJA::Pattern::forall>
+{
+  using seg_it   = SEG_ITER_POLICY_T;
   using seg_exec = SEG_EXEC_POLICY_T;
 };
 
@@ -65,7 +75,6 @@ struct ExecPolicy
 
 using policy::indexset::ExecPolicy;
 
-
 /*!
  ******************************************************************************
  *
@@ -74,10 +83,10 @@ using policy::indexset::ExecPolicy;
  *
  ******************************************************************************
  */
-template <typename T0, typename... TREST>
+template<typename T0, typename... TREST>
 class TypedIndexSet<T0, TREST...> : public TypedIndexSet<TREST...>
 {
-  using PARENT = TypedIndexSet<TREST...>;
+  using PARENT               = TypedIndexSet<TREST...>;
   static const int T0_TypeId = sizeof...(TREST);
 
 public:
@@ -91,7 +100,7 @@ public:
 
   //! Construct empty index set
 #if _MSC_VER < 1910
-   // this one instance of constexpr does not work on VS2012 or VS2015
+  // this one instance of constexpr does not work on VS2012 or VS2015
   RAJA_INLINE TypedIndexSet() : PARENT() {}
 #else
   RAJA_INLINE constexpr TypedIndexSet() : PARENT() {}
@@ -99,12 +108,12 @@ public:
 
   //! Copy-constructor for index set
   RAJA_INLINE
-  TypedIndexSet(TypedIndexSet<T0, TREST...> const &c)
-      : PARENT((PARENT const &)c)
+  TypedIndexSet(TypedIndexSet<T0, TREST...> const& c) : PARENT((PARENT const&)c)
   {
     size_t num = c.data.size();
     data.resize(num);
-    for (size_t i = 0; i < num; ++i) {
+    for (size_t i = 0; i < num; ++i)
+    {
       data[i] = c.data[i];
     }
     // mark all as not owned by us
@@ -112,9 +121,10 @@ public:
   }
 
   //! Copy-assignment operator for index set
-  TypedIndexSet<T0, TREST...> &operator=(const TypedIndexSet<T0, TREST...> &rhs)
+  TypedIndexSet<T0, TREST...>& operator=(const TypedIndexSet<T0, TREST...>& rhs)
   {
-    if (&rhs != this) {
+    if (&rhs != this)
+    {
       TypedIndexSet<T0, TREST...> copy(rhs);
       this->swap(copy);
     }
@@ -125,19 +135,21 @@ public:
   RAJA_INLINE ~TypedIndexSet()
   {
     size_t num_seg = data.size();
-    for (size_t i = 0; i < num_seg; ++i) {
+    for (size_t i = 0; i < num_seg; ++i)
+    {
       // Only free segment of we allocated it
-      if (owner[i]) {
+      if (owner[i])
+      {
         delete data[i];
       }
     }
   }
 
   //! Swap function for copy-and-swap idiom.
-  void swap(TypedIndexSet<T0, TREST...> &other)
+  void swap(TypedIndexSet<T0, TREST...>& other)
   {
     // Swap parents data
-    PARENT::swap((PARENT &)other);
+    PARENT::swap((PARENT&)other);
     // Swap our data
     using std::swap;
     swap(data, other.data);
@@ -149,19 +161,21 @@ public:
   ///
   /// This is used to implement the == and != operators
   ///
-  template <typename P0, typename... PREST>
+  template<typename P0, typename... PREST>
   RAJA_INLINE bool compareSegmentById(
       size_t segid,
-      const TypedIndexSet<P0, PREST...> &other) const
+      const TypedIndexSet<P0, PREST...>& other) const
   {
     // drill down our types until we have the right type
-    if (getSegmentTypes()[segid] != T0_TypeId) {
+    if (getSegmentTypes()[segid] != T0_TypeId)
+    {
       // peel off T0
       return PARENT::compareSegmentById(segid, other);
     }
 
     // Check that other's segid is of type T0
-    if (!other.template checkSegmentType<T0>(segid)) {
+    if (!other.template checkSegmentType<T0>(segid))
+    {
       return false;
     }
 
@@ -170,35 +184,36 @@ public:
     return *data[offset] == other.template getSegment<T0>(segid);
   }
 
-
-  template <typename P0>
+  template<typename P0>
   RAJA_INLINE bool checkSegmentType(size_t segid) const
   {
-    if (getSegmentTypes()[segid] == T0_TypeId) {
+    if (getSegmentTypes()[segid] == T0_TypeId)
+    {
       return std::is_same<T0, P0>::value;
     }
     return PARENT::template checkSegmentType<P0>(segid);
   }
 
-
   //! get specified segment by ID
-  template <typename P0>
-  RAJA_INLINE P0 &getSegment(size_t segid)
+  template<typename P0>
+  RAJA_INLINE P0& getSegment(size_t segid)
   {
-    if (getSegmentTypes()[segid] == T0_TypeId) {
+    if (getSegmentTypes()[segid] == T0_TypeId)
+    {
       Index_type offset = getSegmentOffsets()[segid];
-      return *reinterpret_cast<P0 const *>(data[offset]);
+      return *reinterpret_cast<P0 const*>(data[offset]);
     }
     return PARENT::template getSegment<P0>(segid);
   }
 
   //! get specified segment by ID
-  template <typename P0>
-  RAJA_INLINE P0 const &getSegment(size_t segid) const
+  template<typename P0>
+  RAJA_INLINE P0 const& getSegment(size_t segid) const
   {
-    if (getSegmentTypes()[segid] == T0_TypeId) {
+    if (getSegmentTypes()[segid] == T0_TypeId)
+    {
       Index_type offset = getSegmentOffsets()[segid];
-      return *reinterpret_cast<P0 const *>(data[offset]);
+      return *reinterpret_cast<P0 const*>(data[offset]);
     }
     return PARENT::template getSegment<P0>(segid);
   }
@@ -230,43 +245,49 @@ public:
   ///
 
 private:
-  template <typename... CALL>
-  RAJA_INLINE void push_into(TypedIndexSet<CALL...> &c,
-                             PushEnd pend = PUSH_BACK,
+  template<typename... CALL>
+  RAJA_INLINE void push_into(TypedIndexSet<CALL...>& c,
+                             PushEnd pend   = PUSH_BACK,
                              PushCopy pcopy = PUSH_COPY)
   {
     Index_type num = getNumSegments();
 
-    if (pend == PUSH_BACK) {
-      for (Index_type i = 0; i < num; ++i) {
+    if (pend == PUSH_BACK)
+    {
+      for (Index_type i = 0; i < num; ++i)
+      {
         segment_push_into(i, c, pend, pcopy);
-      } 
-    } else {
-      for (Index_type i = num-1; i > -1; --i) {
+      }
+    }
+    else
+    {
+      for (Index_type i = num - 1; i > -1; --i)
+      {
         segment_push_into(i, c, pend, pcopy);
-      } 
+      }
     }
   }
 
-
   static constexpr int value_for(PushEnd end, PushCopy copy)
   {
     return (end == PUSH_BACK) << 1 | (copy == PUSH_COPY);
   }
 
 public:
-  template <typename... CALL>
+  template<typename... CALL>
   RAJA_INLINE void segment_push_into(size_t segid,
-                                     TypedIndexSet<CALL...> &c,
-                                     PushEnd pend = PUSH_BACK,
+                                     TypedIndexSet<CALL...>& c,
+                                     PushEnd pend   = PUSH_BACK,
                                      PushCopy pcopy = PUSH_COPY)
   {
-    if (getSegmentTypes()[segid] != T0_TypeId) {
+    if (getSegmentTypes()[segid] != T0_TypeId)
+    {
       PARENT::segment_push_into(segid, c, pend, pcopy);
       return;
     }
     Index_type offset = getSegmentOffsets()[segid];
-    switch (value_for(pend, pcopy)) {
+    switch (value_for(pend, pcopy))
+    {
       case value_for(PUSH_BACK, PUSH_COPY):
         c.push_back(*data[offset]);
         break;
@@ -282,41 +303,43 @@ public:
     }
   }
 
-
   //! Add segment to back end of index set without making a copy.
-  template <typename Tnew>
-  RAJA_INLINE void push_back_nocopy(Tnew *val)
+  template<typename Tnew>
+  RAJA_INLINE void push_back_nocopy(Tnew* val)
   {
     push_internal(val, PUSH_BACK, PUSH_NOCOPY);
   }
 
   //! Add segment to front end of index set without making a copy.
-  template <typename Tnew>
-  RAJA_INLINE void push_front_nocopy(Tnew *val)
+  template<typename Tnew>
+  RAJA_INLINE void push_front_nocopy(Tnew* val)
   {
     push_internal(val, PUSH_FRONT, PUSH_NOCOPY);
   }
 
   //! Add copy of segment to back end of index set.
-  template <typename Tnew>
-  RAJA_INLINE void push_back(Tnew const &val)
+  template<typename Tnew>
+  RAJA_INLINE void push_back(Tnew&& val)
   {
-    push_internal(new Tnew(val), PUSH_BACK, PUSH_COPY);
+    push_internal(new typename std::decay<Tnew>::type(std::forward<Tnew>(val)),
+                  PUSH_BACK, PUSH_COPY);
   }
 
   //! Add copy of segment to front end of index set.
-  template <typename Tnew>
-  RAJA_INLINE void push_front(Tnew const &val)
+  template<typename Tnew>
+  RAJA_INLINE void push_front(Tnew&& val)
   {
-    push_internal(new Tnew(val), PUSH_FRONT, PUSH_COPY);
+    push_internal(new typename std::decay<Tnew>::type(std::forward<Tnew>(val)),
+                  PUSH_FRONT, PUSH_COPY);
   }
 
   //! Return total length -- sum of lengths of all segments
   RAJA_INLINE size_t getLength() const
   {
     size_t total = PARENT::getLength();
-    size_t num = data.size();
-    for (size_t i = 0; i < num; ++i) {
+    size_t num   = data.size();
+    for (size_t i = 0; i < num; ++i)
+    {
       total += data[i]->size();
     }
     return total;
@@ -328,7 +351,6 @@ public:
     return data.size() + PARENT::getNumSegments();
   }
 
-
   ///
   /// Calls the operator "body" with the segment stored at segid.
   ///
@@ -338,14 +360,14 @@ public:
   /// The "args..." are passed-thru to the body as arguments AFTER the segment.
   ///
   RAJA_SUPPRESS_HD_WARN
-  template <typename BODY, typename... ARGS>
+  template<typename BODY, typename... ARGS>
   RAJA_HOST_DEVICE void segmentCall(size_t segid,
-                                    BODY &&body,
-                                    ARGS &&... args) const
+                                    BODY&& body,
+                                    ARGS&&... args) const
   {
-    if (getSegmentTypes()[segid] != T0_TypeId) {
-      PARENT::segmentCall(segid,
-                          std::forward<BODY>(body),
+    if (getSegmentTypes()[segid] != T0_TypeId)
+    {
+      PARENT::segmentCall(segid, std::forward<BODY>(body),
                           std::forward<ARGS>(args)...);
       return;
     }
@@ -355,9 +377,9 @@ public:
 
 protected:
   //! Internal logic to add a new segment -- catch invalid type insertion
-  template <typename Tnew>
-  RAJA_INLINE void push_internal(Tnew *val,
-                                 PushEnd pend = PUSH_BACK,
+  template<typename Tnew>
+  RAJA_INLINE void push_internal(Tnew* val,
+                                 PushEnd pend   = PUSH_BACK,
                                  PushCopy pcopy = PUSH_COPY)
   {
     static_assert(sizeof...(TREST) > 0, "Invalid type for this TypedIndexSet");
@@ -365,15 +387,16 @@ protected:
   }
 
   //! Internal logic to add a new segment
-  RAJA_INLINE void push_internal(T0 *val,
-                                 PushEnd pend = PUSH_BACK,
+  RAJA_INLINE void push_internal(T0* val,
+                                 PushEnd pend   = PUSH_BACK,
                                  PushCopy pcopy = PUSH_COPY)
   {
     data.push_back(val);
     owner.push_back(pcopy == PUSH_COPY);
 
     // Determine if we push at the front or back of the segment list
-    if (pend == PUSH_BACK) {
+    if (pend == PUSH_BACK)
+    {
       // Store the segment type
       getSegmentTypes().push_back(T0_TypeId);
 
@@ -384,7 +407,9 @@ protected:
       size_t icount = val->size();
       getSegmentIcounts().push_back(getTotalLength());
       increaseTotalLength(icount);
-    } else {
+    }
+    else
+    {
       // Store the segment type
       getSegmentTypes().push_front(T0_TypeId);
 
@@ -394,7 +419,8 @@ protected:
       // Store the segment icount
       getSegmentIcounts().push_front(0);
       size_t icount = val->size();
-      for (size_t i = 1; i < getSegmentIcounts().size(); ++i) {
+      for (size_t i = 1; i < getSegmentIcounts().size(); ++i)
+      {
         getSegmentIcounts()[i] += icount;
       }
       increaseTotalLength(icount);
@@ -402,7 +428,7 @@ protected:
   }
 
   //! Returns the number of indices (the total icount of segments
-  RAJA_INLINE Index_type &getTotalLength() { return PARENT::getTotalLength(); }
+  RAJA_INLINE Index_type& getTotalLength() { return PARENT::getTotalLength(); }
 
   //! set total length of the indexset
   RAJA_INLINE void setTotalLength(int n) { return PARENT::setTotalLength(n); }
@@ -437,9 +463,10 @@ public:
   {
     TypedIndexSet<T0, TREST...> retVal;
 
-    int minSeg = RAJA::operators::maximum<int>{}(0, begin);
-    int maxSeg = RAJA::operators::minimum<int>{}(end, getNumSegments());
-    for (int i = minSeg; i < maxSeg; ++i) {
+    int minSeg = RAJA::operators::maximum<int> {}(0, begin);
+    int maxSeg = RAJA::operators::minimum<int> {}(end, getNumSegments());
+    for (int i = minSeg; i < maxSeg; ++i)
+    {
       segment_push_into(i, retVal, PUSH_BACK, PUSH_NOCOPY);
     }
     return retVal;
@@ -452,13 +479,15 @@ public:
   /// This TypedIndexSet will not change and the created "slice" into it
   /// will not own any of its segments.
   ///
-  TypedIndexSet<T0, TREST...> createSlice(const int *segIds, int len)
+  TypedIndexSet<T0, TREST...> createSlice(const int* segIds, int len)
   {
     TypedIndexSet<T0, TREST...> retVal;
 
     int numSeg = getNumSegments();
-    for (int i = 0; i < len; ++i) {
-      if (segIds[i] >= 0 && segIds[i] < numSeg) {
+    for (int i = 0; i < len; ++i)
+    {
+      if (segIds[i] >= 0 && segIds[i] < numSeg)
+      {
         segment_push_into(segIds[i], retVal, PUSH_BACK, PUSH_NOCOPY);
       }
     }
@@ -475,13 +504,15 @@ public:
   /// The object must provide methods begin(), end(), and its
   /// iterator type must de-reference to an integral value.
   ///
-  template <typename T>
-  TypedIndexSet<T0, TREST...> createSlice(const T &segIds)
+  template<typename T>
+  TypedIndexSet<T0, TREST...> createSlice(const T& segIds)
   {
     TypedIndexSet<T0, TREST...> retVal;
     int numSeg = getNumSegments();
-    for (auto &seg : segIds) {
-      if (seg >= 0 && seg < numSeg) {
+    for (auto& seg : segIds)
+    {
+      if (seg >= 0 && seg < numSeg)
+      {
         segment_push_into(seg, retVal, PUSH_BACK, PUSH_NOCOPY);
       }
     }
@@ -492,7 +523,7 @@ public:
   void setSegmentInterval(size_t interval_id, int begin, int end)
   {
     m_seg_interval_begin[interval_id] = begin;
-    m_seg_interval_end[interval_id] = end;
+    m_seg_interval_end[interval_id]   = end;
   }
 
   //! get lower bound of segment identified with interval_id
@@ -509,37 +540,37 @@ public:
 
 protected:
   //! Returns the mapping of  segment_index -> segment_type
-  RAJA_INLINE RAJA::RAJAVec<Index_type> &getSegmentTypes()
+  RAJA_INLINE RAJA::RAJAVec<Index_type>& getSegmentTypes()
   {
     return PARENT::getSegmentTypes();
   }
 
   //! Returns the mapping of  segment_index -> segment_type
-  RAJA_INLINE RAJA::RAJAVec<Index_type> const &getSegmentTypes() const
+  RAJA_INLINE RAJA::RAJAVec<Index_type> const& getSegmentTypes() const
   {
     return PARENT::getSegmentTypes();
   }
 
   //! Returns the mapping of  segment_index -> segment_offset
-  RAJA_INLINE RAJA::RAJAVec<Index_type> &getSegmentOffsets()
+  RAJA_INLINE RAJA::RAJAVec<Index_type>& getSegmentOffsets()
   {
     return PARENT::getSegmentOffsets();
   }
 
   //! Returns the mapping of  segment_index -> segment_offset
-  RAJA_INLINE RAJA::RAJAVec<Index_type> const &getSegmentOffsets() const
+  RAJA_INLINE RAJA::RAJAVec<Index_type> const& getSegmentOffsets() const
   {
     return PARENT::getSegmentOffsets();
   }
 
   //! Returns the icount of segments
-  RAJA_INLINE RAJA::RAJAVec<Index_type> &getSegmentIcounts()
+  RAJA_INLINE RAJA::RAJAVec<Index_type>& getSegmentIcounts()
   {
     return PARENT::getSegmentIcounts();
   }
 
   //! Returns the icount of segments
-  RAJA_INLINE RAJA::RAJAVec<Index_type> const &getSegmentIcounts() const
+  RAJA_INLINE RAJA::RAJAVec<Index_type> const& getSegmentIcounts() const
   {
     return PARENT::getSegmentIcounts();
   }
@@ -551,14 +582,16 @@ public:
   /// Note: method does not check equality of anything other than segment
   ///       types and indices; e.g., dependency info not checked.
   ///
-  template <typename P0, typename... PREST>
-  RAJA_INLINE bool operator==(const TypedIndexSet<P0, PREST...> &other) const
+  template<typename P0, typename... PREST>
+  RAJA_INLINE bool operator==(const TypedIndexSet<P0, PREST...>& other) const
   {
     size_t num_seg = getNumSegments();
     if (num_seg != other.getNumSegments()) return false;
 
-    for (size_t segid = 0; segid < num_seg; ++segid) {
-      if (!compareSegmentById(segid, other)) {
+    for (size_t segid = 0; segid < num_seg; ++segid)
+    {
+      if (!compareSegmentById(segid, other))
+      {
         return false;
       }
     }
@@ -566,15 +599,15 @@ public:
   }
 
   //! Inequality operator returns true if any segment is not equal, else false.
-  template <typename P0, typename... PREST>
-  RAJA_INLINE bool operator!=(const TypedIndexSet<P0, PREST...> &other) const
+  template<typename P0, typename... PREST>
+  RAJA_INLINE bool operator!=(const TypedIndexSet<P0, PREST...>& other) const
   {
     return (!(*this == other));
   }
 
 private:
   //! vector of TypedIndexSet data objects of type T0
-  RAJA::RAJAVec<T0 *> data;
+  RAJA::RAJAVec<T0*> data;
 
   //! vector indicating which segments are owned by the TypedIndexSet
   RAJA::RAJAVec<Index_type> owner;
@@ -586,8 +619,7 @@ private:
   RAJA::RAJAVec<Index_type> m_seg_interval_end;
 };
 
-
-template <>
+template<>
 class TypedIndexSet<>
 {
 public:
@@ -603,16 +635,16 @@ public:
 
   //! Copy-constructor.
   RAJA_INLINE
-  TypedIndexSet(TypedIndexSet const &c)
+  TypedIndexSet(TypedIndexSet const& c)
   {
-    segment_types = c.segment_types;
+    segment_types   = c.segment_types;
     segment_offsets = c.segment_offsets;
     segment_icounts = c.segment_icounts;
-    m_len = c.m_len;
+    m_len           = c.m_len;
   }
 
   //! Swap function for copy-and-swap idiom (deep copy).
-  void swap(TypedIndexSet &other)
+  void swap(TypedIndexSet& other)
   {
     using std::swap;
     swap(segment_types, other.segment_types);
@@ -624,8 +656,8 @@ public:
 protected:
   RAJA_INLINE static size_t getNumTypes() { return 0; }
 
-  template <typename T>
-  RAJA_INLINE constexpr bool isValidSegmentType(T const &) const
+  template<typename T>
+  RAJA_INLINE constexpr bool isValidSegmentType(T const&) const
   {
     // Segment type wasn't found
     return false;
@@ -635,89 +667,85 @@ protected:
 
   RAJA_INLINE static size_t getLength() { return 0; }
 
-  template <typename BODY, typename... ARGS>
+  template<typename BODY, typename... ARGS>
   RAJA_INLINE void segmentCall(size_t, BODY, ARGS...) const
-  {
-  }
+  {}
 
-  RAJA_INLINE RAJA::RAJAVec<Index_type> &getSegmentTypes()
+  RAJA_INLINE RAJA::RAJAVec<Index_type>& getSegmentTypes()
   {
     return segment_types;
   }
 
-  RAJA_INLINE RAJA::RAJAVec<Index_type> const &getSegmentTypes() const
+  RAJA_INLINE RAJA::RAJAVec<Index_type> const& getSegmentTypes() const
   {
     return segment_types;
   }
 
-  RAJA_INLINE RAJA::RAJAVec<Index_type> &getSegmentOffsets()
+  RAJA_INLINE RAJA::RAJAVec<Index_type>& getSegmentOffsets()
   {
     return segment_offsets;
   }
 
-  RAJA_INLINE RAJA::RAJAVec<Index_type> const &getSegmentOffsets() const
+  RAJA_INLINE RAJA::RAJAVec<Index_type> const& getSegmentOffsets() const
   {
     return segment_offsets;
   }
 
-  RAJA_INLINE RAJA::RAJAVec<Index_type> &getSegmentIcounts()
+  RAJA_INLINE RAJA::RAJAVec<Index_type>& getSegmentIcounts()
   {
     return segment_icounts;
   }
 
-  RAJA_INLINE RAJA::RAJAVec<Index_type> const &getSegmentIcounts() const
+  RAJA_INLINE RAJA::RAJAVec<Index_type> const& getSegmentIcounts() const
   {
     return segment_icounts;
   }
 
-  RAJA_INLINE Index_type &getTotalLength() { return m_len; }
+  RAJA_INLINE Index_type& getTotalLength() { return m_len; }
 
   RAJA_INLINE void setTotalLength(int n) { m_len = n; }
 
   RAJA_INLINE void increaseTotalLength(int n) { m_len += n; }
 
-  template <typename P0, typename... PREST>
+  template<typename P0, typename... PREST>
   RAJA_INLINE bool compareSegmentById(size_t,
-                                      const TypedIndexSet<P0, PREST...> &) const
+                                      const TypedIndexSet<P0, PREST...>&) const
   {
     return false;
   }
 
-  template <typename P0>
+  template<typename P0>
   RAJA_INLINE bool checkSegmentType(size_t) const
   {
     return false;
   }
 
-  template <typename P0>
-  RAJA_INLINE P0 &getSegment(size_t)
+  template<typename P0>
+  RAJA_INLINE P0& getSegment(size_t)
   {
-    return *((P0 *)(this - this));
+    return *((P0*)(this - this));
   }
 
-  template <typename P0>
-  RAJA_INLINE P0 const &getSegment(size_t) const
+  template<typename P0>
+  RAJA_INLINE P0 const& getSegment(size_t) const
   {
-    return *((P0 *)(this - this));
+    return *((P0*)(this - this));
   }
 
-  template <typename... CALL>
-  RAJA_INLINE void push_into(TypedIndexSet<CALL...> &, PushEnd, PushCopy) const
-  {
-  }
+  template<typename... CALL>
+  RAJA_INLINE void push_into(TypedIndexSet<CALL...>&, PushEnd, PushCopy) const
+  {}
 
-  template <typename... CALL>
+  template<typename... CALL>
   RAJA_INLINE void segment_push_into(size_t,
-                                     TypedIndexSet<CALL...> &,
+                                     TypedIndexSet<CALL...>&,
                                      PushEnd,
                                      PushCopy) const
-  {
-  }
+  {}
 
-  template <typename Tnew>
-  RAJA_INLINE void push(Tnew const &, PushEnd, PushCopy)
-  {
-  }
+  template<typename Tnew>
+  RAJA_INLINE void push(Tnew const&, PushEnd, PushCopy)
+  {}
 
 public:
   using iterator = Iterators::numeric_iterator<Index_type>;
@@ -756,19 +784,20 @@ private:
   Index_type m_len;
 };
 
-
 namespace type_traits
 {
 
-template <typename T>
+template<typename T>
 struct is_index_set
-    : ::RAJA::type_traits::SpecializationOf<RAJA::TypedIndexSet, typename std::decay<T>::type> {
-};
+    : ::RAJA::type_traits::SpecializationOf<RAJA::TypedIndexSet,
+                                            typename std::decay<T>::type>
+{};
 
-template <typename T>
+template<typename T>
 struct is_indexset_policy
-    : ::RAJA::type_traits::SpecializationOf<RAJA::ExecPolicy, typename std::decay<T>::type> {
-};
+    : ::RAJA::type_traits::SpecializationOf<RAJA::ExecPolicy,
+                                            typename std::decay<T>::type>
+{};
 }  // namespace type_traits
 
 }  // namespace RAJA
