@@ -9,8 +9,8 @@
  */
 
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
-// Copyright (c) 2016-21, Lawrence Livermore National Security, LLC
-// and RAJA project contributors. See the RAJA/COPYRIGHT file for details.
+// Copyright (c) 2016-25, Lawrence Livermore National Security, LLC
+// and RAJA project contributors. See the RAJA/LICENSE file for details.
 //
 // SPDX-License-Identifier: (BSD-3-Clause)
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
@@ -50,10 +50,10 @@ namespace RAJA
  *
  * NOTE: TypedRangeSegment::iterator is a RandomAccessIterator
  *
- * NOTE: TypedRangeSegment supports negative indices; e.g., an interval of 
+ * NOTE: TypedRangeSegment supports negative indices; e.g., an interval of
  *       indices [-5, 3).
  *
- * NOTE: Proper handling of indices strides requires that StorageT is a 
+ * NOTE: Proper handling of indices strides requires that StorageT is a
  *       signed type.
  *
  * Usage:
@@ -92,15 +92,19 @@ namespace RAJA
  *
  ******************************************************************************
  */
-template <typename StorageT, typename DiffT = make_signed_t<strip_index_type_t<StorageT>>>
-struct TypedRangeSegment {
+template<typename StorageT,
+         typename DiffT = make_signed_t<strip_index_type_t<StorageT>>>
+struct TypedRangeSegment
+{
 
-  // 
+  //
   // Static asserts to provide some useful error messages during compilation
   // for incorrect usage.
-  // 
-  static_assert(std::is_signed<DiffT>::value, "TypedRangeSegment DiffT requires signed type.");
-  static_assert(!std::is_floating_point<StorageT>::value, "TypedRangeSegment Type must be non floating point.");
+  //
+  static_assert(std::is_signed<DiffT>::value,
+                "TypedRangeSegment DiffT requires signed type.");
+  static_assert(!std::is_floating_point<StorageT>::value,
+                "TypedRangeSegment Type must be non floating point.");
 
   //@{
   //!   @name Types used in implementation based on template parameters.
@@ -117,20 +121,21 @@ struct TypedRangeSegment {
   //@}
 
   //@{
-  //!   @name Constructors, destructor, and copy assignment. 
+  //!   @name Constructors, destructor, and copy assignment.
 
   /*!
    * \brief Construct a range segment repreenting the interval [begin, end)
-   * 
+   *
    * \param begin start value (inclusive) for the range
    * \param end end value (exclusive) for the range
    */
   using StripStorageT = strip_index_type_t<StorageT>;
-  RAJA_HOST_DEVICE constexpr TypedRangeSegment(StripStorageT begin, StripStorageT end)
-      : m_begin(iterator(begin)), 
+
+  RAJA_HOST_DEVICE constexpr TypedRangeSegment(StripStorageT begin,
+                                               StripStorageT end)
+      : m_begin(iterator(begin)),
         m_end(begin > end ? m_begin : iterator(end))
-  {
-  }
+  {}
 
   //! Disable compiler generated constructor
   RAJA_HOST_DEVICE TypedRangeSegment() = delete;
@@ -187,7 +192,7 @@ struct TypedRangeSegment {
    * \brief Compare this segment to another for inequality
    *
    * \return true if begin or end does not match, else false
-   */ 
+   */
   RAJA_HOST_DEVICE RAJA_INLINE bool operator!=(TypedRangeSegment const& o) const
   {
     return !(operator==(o));
@@ -198,9 +203,9 @@ struct TypedRangeSegment {
   /*!
    * \brief Get a new TypedRangeSegment instance representing a slice of
    *        existing segment
-   * 
-   * \param begin start iterate of new range 
-   * \param length maximum length of new range 
+   *
+   * \param begin start iterate of new range
+   * \param length maximum length of new range
    * \return TypedRangeSegment representing the interval
    *         [ *begin() + begin, min( *begin() + begin + length, *end() ) )
    *
@@ -213,7 +218,7 @@ struct TypedRangeSegment {
    *     auto r = RAJA::TypedRangeSegment<int>(-4, 4);
    *
    *     // s repreents the subinterval  [-3, 2)
-   *     auto s = r.slice(1, 5); 
+   *     auto s = r.slice(1, 5);
    *
    *   \endverbatim
    */
@@ -221,9 +226,9 @@ struct TypedRangeSegment {
                                                        DiffT length) const
   {
     StorageT start = m_begin[0] + begin;
-    StorageT end = start + length > m_end[0] ? m_end[0] : start + length;
+    StorageT end   = start + length > m_end[0] ? m_end[0] : start + length;
 
-    return TypedRangeSegment{stripIndexType(start), stripIndexType(end)};
+    return TypedRangeSegment {stripIndexType(start), stripIndexType(end)};
   }
 
   /*!
@@ -243,12 +248,11 @@ private:
   iterator m_end;
 };
 
-
 /*!
  ******************************************************************************
  *
- * \class TypedRangeStrideSegment 
- * 
+ * \class TypedRangeStrideSegment
+ *
  * \brief  Segment class representing a strided range of typed indices
  *
  * \tparam StorageT underlying data type for the segment indices (required)
@@ -264,9 +268,9 @@ private:
  *
  * NOTE: TypedRangeStrideSegment::iterator is a RandomAccessIterator
  *
- * NOTE: TypedRangeStrideSegment allows for positive or negative strides and 
- *       indices. This allows for forward (stride > 0) or backward (stride < 0) 
- *       traversal of the iteration space. A stride of zero is undefined and 
+ * NOTE: TypedRangeStrideSegment allows for positive or negative strides and
+ *       indices. This allows for forward (stride > 0) or backward (stride < 0)
+ *       traversal of the iteration space. A stride of zero is undefined and
  *       will cause divide-by-zero errors.
  *
  * As with RangeSegment, the iteration space is inclusive of begin() and
@@ -275,7 +279,7 @@ private:
  * For positive strides, begin() > end() implies size()==0
  * For negative strides, begin() < end() implies size()==0
  *
- * NOTE: Proper handling of negative strides and indices requires that 
+ * NOTE: Proper handling of negative strides and indices requires that
  *       StorageT is a signed type.
  *
  * Usage:
@@ -321,15 +325,19 @@ private:
  *
  ******************************************************************************
  */
-template <typename StorageT, typename DiffT = make_signed_t<strip_index_type_t<StorageT>>>
-struct TypedRangeStrideSegment {
+template<typename StorageT,
+         typename DiffT = make_signed_t<strip_index_type_t<StorageT>>>
+struct TypedRangeStrideSegment
+{
 
   //
   // Static asserts to provide some useful error messages during compilation
   // for incorrect usage.
   //
-  static_assert(std::is_signed<DiffT>::value, "TypedRangeStrideSegment DiffT requires signed type.");
-  static_assert(!std::is_floating_point<StorageT>::value, "TypedRangeStrideSegment Type must be non floating point.");
+  static_assert(std::is_signed<DiffT>::value,
+                "TypedRangeStrideSegment DiffT requires signed type.");
+  static_assert(!std::is_floating_point<StorageT>::value,
+                "TypedRangeStrideSegment Type must be non floating point.");
 
   //@{
   //!   @name Types used in implementation based on template parameters.
@@ -349,7 +357,7 @@ struct TypedRangeStrideSegment {
   //!   @name Constructors, destructor, and copy assignment.
 
   /*!
-   * \brief Construct a range segment for the interval [begin, end) with 
+   * \brief Construct a range segment for the interval [begin, end) with
    *        given stride
    *
    * \param begin start value (inclusive) for the range
@@ -357,6 +365,7 @@ struct TypedRangeStrideSegment {
    * \param stride stride value when iterating over the range
    */
   using StripStorageT = strip_index_type_t<StorageT>;
+
   RAJA_HOST_DEVICE TypedRangeStrideSegment(StripStorageT begin,
                                            StripStorageT end,
                                            DiffT stride)
@@ -367,13 +376,16 @@ struct TypedRangeStrideSegment {
         m_size((end - begin + stride - (stride > 0 ? 1 : -1)) / stride)
   {
     // clamp range when end is unreachable from begin without wrapping
-    if (stride < 0 && end > begin) {
+    if (stride < 0 && end > begin)
+    {
       m_end = m_begin;
-    } else if (stride > 0 && end < begin) {
+    }
+    else if (stride > 0 && end < begin)
+    {
       m_end = m_begin;
     }
     // m_size initialized as negative indicates a zero iteration space
-    m_size = m_size < DiffT{0} ? DiffT{0} : m_size;
+    m_size = m_size < DiffT {0} ? DiffT {0} : m_size;
   }
 
   //! Disable compiler generated constructor
@@ -408,8 +420,8 @@ struct TypedRangeStrideSegment {
 
   /*!
    * \brief Get size of this segment
-   * 
-   * The size is the number of iterates in the 
+   *
+   * The size is the number of iterates in the
    * interval [begin, end) when striding over it
    */
   RAJA_HOST_DEVICE DiffT size() const { return m_size; }
@@ -435,7 +447,8 @@ struct TypedRangeStrideSegment {
    *
    * \return true if begin, end, or size does not match, else false
    */
-  RAJA_HOST_DEVICE RAJA_INLINE bool operator!=(TypedRangeStrideSegment const& o) const
+  RAJA_HOST_DEVICE RAJA_INLINE bool operator!=(
+      TypedRangeStrideSegment const& o) const
   {
     return !(operator==(o));
   }
@@ -450,7 +463,7 @@ struct TypedRangeStrideSegment {
    * \param length maximum length of new range
    *
    * \return TypedRangeStrideSegment representing the interval
-   *         [ *begin() + begin * stride, 
+   *         [ *begin() + begin * stride,
    *           min( *begin() + (begin + length) * stride, *end() )
    *
    * Here's an example of a slice operation on a range segment with a negative
@@ -466,24 +479,26 @@ struct TypedRangeStrideSegment {
    *     //       5 indices in r starting at the 6th entry
    *     auto s = r.slice(6, 6);
    *
-   *   \endverbatim 
+   *   \endverbatim
    */
   RAJA_HOST_DEVICE TypedRangeStrideSegment slice(StorageT begin,
                                                  DiffT length) const
   {
     StorageT stride = m_begin.get_stride();
-    StorageT start = m_begin[0] + begin * stride;
-    StorageT end = start + stride * length;
+    StorageT start  = m_begin[0] + begin * stride;
+    StorageT end    = start + stride * length;
 
-    if (stride > 0) {
+    if (stride > 0)
+    {
       end = end > m_end[0] ? m_end[0] : end;
-    } else {
+    }
+    else
+    {
       end = end < m_end[0] ? m_end[0] : end;
     }
 
-    return TypedRangeStrideSegment{stripIndexType(start),
-                                   stripIndexType(end),
-                                   m_begin.get_stride()};
+    return TypedRangeStrideSegment {stripIndexType(start), stripIndexType(end),
+                                    m_begin.get_stride()};
   }
 
   /*!
@@ -516,17 +531,18 @@ using RangeStrideSegment = TypedRangeStrideSegment<Index_type>;
 namespace detail
 {
 
-template <typename T, typename... Rest>
+template<typename T, typename... Rest>
 struct common_type
-    : std::common_type<T, typename std::common_type<Rest...>::type> {
-};
+    : std::common_type<T, typename std::common_type<Rest...>::type>
+{};
 
-template <typename T>
-struct common_type<T> {
+template<typename T>
+struct common_type<T>
+{
   using type = T;
 };
 
-template <typename... Ts>
+template<typename... Ts>
 using common_type_t = typename common_type<Ts...>::type;
 
 }  // namespace detail
@@ -539,9 +555,9 @@ using common_type_t = typename common_type<Ts...>::type;
  *          @begin and @end. If there is no common type, then
  *          a compiler error will be produced.
  */
-template <typename BeginT,
-          typename EndT,
-          typename Common = detail::common_type_t<BeginT, EndT>>
+template<typename BeginT,
+         typename EndT,
+         typename Common = detail::common_type_t<BeginT, EndT>>
 RAJA_HOST_DEVICE TypedRangeSegment<Common> make_range(BeginT&& begin,
                                                       EndT&& end)
 {
@@ -549,7 +565,7 @@ RAJA_HOST_DEVICE TypedRangeSegment<Common> make_range(BeginT&& begin,
 }
 
 /*!
- * \brief Function to make a TypedRangeStride Segment for the interval 
+ * \brief Function to make a TypedRangeStride Segment for the interval
  *        [begin, end) with given stride
  *
  *  \return a newly constructed TypedRangeStrideSegment where
@@ -557,32 +573,35 @@ RAJA_HOST_DEVICE TypedRangeSegment<Common> make_range(BeginT&& begin,
  *          @begin, @end, and @stride. If there is no common
  *          type, then a compiler error will be produced.
  */
-template <typename BeginT,
-          typename EndT,
-          typename StrideT,
-          typename Common = detail::common_type_t<BeginT, EndT>>
+template<typename BeginT,
+         typename EndT,
+         typename StrideT,
+         typename Common = detail::common_type_t<BeginT, EndT>>
 RAJA_HOST_DEVICE TypedRangeStrideSegment<Common> make_strided_range(
     BeginT&& begin,
     EndT&& end,
     StrideT&& stride)
 {
-  static_assert(std::is_signed<StrideT>::value, "make_strided_segment : stride must be signed.");
-  static_assert(std::is_same<make_signed_t<EndT>, StrideT>::value, "make_stride_segment : stride and end must be of similar types.");
+  static_assert(std::is_signed<StrideT>::value,
+                "make_strided_segment : stride must be signed.");
+  static_assert(
+      std::is_same<make_signed_t<EndT>, StrideT>::value,
+      "make_stride_segment : stride and end must be of similar types.");
   return {begin, end, stride};
 }
 
 namespace concepts
 {
 
-template <typename T, typename U>
+template<typename T, typename U>
 struct RangeConstructible
-    : DefineConcept(camp::val<RAJA::detail::common_type_t<T, U>>()) {
-};
+    : DefineConcept(camp::val<RAJA::detail::common_type_t<T, U>>())
+{};
 
-template <typename T, typename U, typename V>
+template<typename T, typename U, typename V>
 struct RangeStrideConstructible
-    : DefineConcept(camp::val<RAJA::detail::common_type_t<T, U, V>>()) {
-};
+    : DefineConcept(camp::val<RAJA::detail::common_type_t<T, U, V>>())
+{};
 
 }  // namespace concepts
 
@@ -603,7 +622,7 @@ namespace std
 {
 
 //! Specialization of std::swap for TypedRangeSegment
-template <typename T>
+template<typename T>
 RAJA_HOST_DEVICE RAJA_INLINE void swap(RAJA::TypedRangeSegment<T>& a,
                                        RAJA::TypedRangeSegment<T>& b)
 {
@@ -611,7 +630,7 @@ RAJA_HOST_DEVICE RAJA_INLINE void swap(RAJA::TypedRangeSegment<T>& a,
 }
 
 //! Specialization of std::swap for TypedRangeStrideSegment
-template <typename T>
+template<typename T>
 RAJA_HOST_DEVICE RAJA_INLINE void swap(RAJA::TypedRangeStrideSegment<T>& a,
                                        RAJA::TypedRangeStrideSegment<T>& b)
 {
