@@ -9,8 +9,8 @@
  */
 
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
-// Copyright (c) 2016-21, Lawrence Livermore National Security, LLC
-// and RAJA project contributors. See the RAJA/COPYRIGHT file for details.
+// Copyright (c) 2016-25, Lawrence Livermore National Security, LLC
+// and RAJA project contributors. See the RAJA/LICENSE file for details.
 //
 // SPDX-License-Identifier: (BSD-3-Clause)
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
@@ -28,25 +28,24 @@ namespace internal
 {
 
 
-
-template <typename ExecPolicy, typename... EnclosedStmts>
-struct Statement {
-  static_assert(std::is_same<ExecPolicy, camp::nil>::value || sizeof...(EnclosedStmts) > 0,
-      "Executable statement with no enclosed statements, this is almost certainly a bug");
+template<typename ExecPolicy, typename... EnclosedStmts>
+struct Statement
+{
+  static_assert(std::is_same<ExecPolicy, camp::nil>::value ||
+                    sizeof...(EnclosedStmts) > 0,
+                "Executable statement with no enclosed statements, this is "
+                "almost certainly a bug");
   Statement() = delete;
 
   using enclosed_statements_t = StatementList<EnclosedStmts...>;
-  using execution_policy_t = ExecPolicy;
+  using execution_policy_t    = ExecPolicy;
 };
 
 
-
-
-template <typename Policy, typename Types>
+template<typename Policy, typename Types>
 struct StatementExecutor;
 
 
-
 }  // end namespace internal
 }  // end namespace RAJA
 
