@@ -10,8 +10,8 @@
  */
 
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
-// Copyright (c) 2016-21, Lawrence Livermore National Security, LLC
-// and RAJA project contributors. See the RAJA/COPYRIGHT file for details.
+// Copyright (c) 2016-25, Lawrence Livermore National Security, LLC
+// and RAJA project contributors. See the RAJA/LICENSE file for details.
 //
 // SPDX-License-Identifier: (BSD-3-Clause)
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
@@ -44,10 +44,20 @@ namespace RAJA
 {
 
 /*!
- * CUDA kernel launch policy where the user may specify the number of physical
+ * CUDA kernel launch policy where the user specifies the number of physical
+ * thread blocks, threads per block, and blocks per SM.
+ * If num_blocks is 0 then num_blocks is chosen at runtime.
+ * Num_blocks is chosen to maximize the number of blocks running concurrently.
+ * Blocks per SM must be chosen by the user.
+ */
+template<bool async0, int num_blocks, int num_threads, int blocks_per_sm>
+struct cuda_explicit_launch
+{};
+
+/*!
+ * CUDA kernel launch policy where the user specifies the number of physical
  * thread blocks and threads per block.
- * If num_blocks is 0 and num_threads is non-zero then num_blocks is chosen at
- * runtime.
+ * If num_blocks is 0 then num_blocks is chosen at runtime.
  * Num_blocks is chosen to maximize the number of blocks running concurrently.
  * If num_threads and num_blocks are both 0 then num_threads and num_blocks are
  * chosen at runtime.
@@ -55,41 +65,41 @@ namespace RAJA
  * If num_threads is 0 and num_blocks is non-zero then num_threads is chosen at
  * runtime.
  * Num_threads is 1024, which may not be appropriate for all kernels.
+ * Blocks per SM defaults to 1.
  */
-template <bool async0, size_t num_blocks, size_t num_threads, size_t blocks_per_sm>
-struct cuda_launch {};
-
-/*!
- * CUDA kernel launch policy where the user specifies the number of physical
- * thread blocks and threads per block.
- * If num_blocks is 0 then num_blocks is chosen at runtime.
- * Num_blocks is chosen to maximize the number of blocks running concurrently.
- */
-template <bool async0, size_t num_blocks, size_t num_threads, size_t blocks_per_sm>
-using cuda_explicit_launch = cuda_launch<async0, num_blocks, num_threads, blocks_per_sm>;
-
+template<bool async0, int num_blocks, int num_threads>
+using cuda_launch = cuda_explicit_launch<async0,
+                                         num_blocks,
+                                         num_threads,
+                                         policy::cuda::MIN_BLOCKS_PER_SM>;
 
 /*!
  * CUDA kernel launch policy where the number of physical blocks and threads
  * are determined by the CUDA occupancy calculator.
  * If num_threads is 0 then num_threads is chosen at runtime.
  */
-template <size_t num_threads0, bool async0>
-using cuda_occ_calc_launch = cuda_launch<async0, 0, num_threads0, 0>;
+template<int num_threads0, bool async0>
+using cuda_occ_calc_launch =
+    cuda_explicit_launch<async0,
+                         0,
+                         num_threads0,
+                         policy::cuda::MIN_BLOCKS_PER_SM>;
 
 namespace statement
 {
 
 /*!
  * A RAJA::kernel statement that launches a CUDA kernel.
- *
- *
+ * Note - Statement requires a placeholder cuda_exec policy for the sake of
+ * object oriented inheritance.
  */
-template <typename LaunchConfig, typename... EnclosedStmts>
+template<typename LaunchConfig, typename... EnclosedStmts>
 struct CudaKernelExt
-    : public internal::Statement<cuda_exec<0>, EnclosedStmts...> {
-};
-
+    : public internal::Statement<
+          ::RAJA::policy::cuda::
+              cuda_exec_explicit<LaunchConfig, void, void, 0, true>,
+          EnclosedStmts...>
+{};
 
 /*!
  * A RAJA::kernel statement that launches a CUDA kernel with the flexibility
@@ -97,9 +107,9 @@ struct CudaKernelExt
  * calculator determine the unspecified values.
  * The kernel launch is synchronous.
  */
-template <size_t num_blocks, size_t num_threads, size_t blocks_per_sm, typename... EnclosedStmts>
-using CudaKernelExp =
-    CudaKernelExt<cuda_launch<false, num_blocks, num_threads, blocks_per_sm>, EnclosedStmts...>;
+template<int num_blocks, int num_threads, typename... EnclosedStmts>
+using CudaKernelExp = CudaKernelExt<cuda_launch<false, num_blocks, num_threads>,
+                                    EnclosedStmts...>;
 
 /*!
  * A RAJA::kernel statement that launches a CUDA kernel with the flexibility
@@ -107,16 +117,16 @@ using CudaKernelExp =
  * calculator determine the unspecified values.
  * The kernel launch is asynchronous.
  */
-template <size_t num_blocks, size_t num_threads, size_t blocks_per_sm, typename... EnclosedStmts>
+template<int num_blocks, int num_threads, typename... EnclosedStmts>
 using CudaKernelExpAsync =
-    CudaKernelExt<cuda_launch<true, num_blocks, num_threads, blocks_per_sm>, EnclosedStmts...>;
+    CudaKernelExt<cuda_launch<true, num_blocks, num_threads>, EnclosedStmts...>;
 
 /*!
  * A RAJA::kernel statement that launches a CUDA kernel using the
  * CUDA occupancy calculator to determine the optimal number of threads.
  * The kernel launch is synchronous.
  */
-template <typename... EnclosedStmts>
+template<typename... EnclosedStmts>
 using CudaKernelOcc =
     CudaKernelExt<cuda_occ_calc_launch<1024, false>, EnclosedStmts...>;
 
@@ -125,7 +135,7 @@ using CudaKernelOcc =
  * CUDA occupancy calculator to determine the optimal number of threads.
  * The kernel launch is asynchronous.
  */
-template <typename... EnclosedStmts>
+template<typename... EnclosedStmts>
 using CudaKernelOccAsync =
     CudaKernelExt<cuda_occ_calc_launch<1024, true>, EnclosedStmts...>;
 
@@ -134,29 +144,32 @@ using CudaKernelOccAsync =
  * number of threads (specified by num_threads)
  * The kernel launch is synchronous.
  */
-template <size_t num_threads, typename... EnclosedStmts>
-using CudaKernelFixed =
-    CudaKernelExt<cuda_explicit_launch<false, operators::limits<size_t>::max(), num_threads, 1>,
-                  EnclosedStmts...>;
-
-/*!
- * A RAJA::kernel statement that launches a CUDA kernel with a fixed
- * number of threads (specified by num_threads) and min blocks per sm.
- * The kernel launch is synchronous.
- */
-template <size_t num_threads, size_t blocks_per_sm, typename... EnclosedStmts>
-using CudaKernelFixedSM =
-    CudaKernelExt<cuda_explicit_launch<false, operators::limits<size_t>::max(), num_threads, blocks_per_sm>,
-                  EnclosedStmts...>;
+template<int num_threads, typename... EnclosedStmts>
+using CudaKernelFixed = CudaKernelExt<
+    cuda_launch<false, operators::limits<int>::max(), num_threads>,
+    EnclosedStmts...>;
 
 /*!
  * A RAJA::kernel statement that launches a CUDA kernel with a fixed
  * number of threads (specified by num_threads)
  * The kernel launch is asynchronous.
  */
-template <size_t num_threads, typename... EnclosedStmts>
+template<int num_threads, typename... EnclosedStmts>
 using CudaKernelFixedAsync =
-    CudaKernelExt<cuda_explicit_launch<true, operators::limits<size_t>::max(), num_threads, 1>,
+    CudaKernelExt<cuda_launch<true, operators::limits<int>::max(), num_threads>,
+                  EnclosedStmts...>;
+
+/*!
+ * A RAJA::kernel statement that launches a CUDA kernel with a fixed
+ * number of threads (specified by num_threads) and min blocks per sm.
+ * The kernel launch is synchronous.
+ */
+template<int num_threads, int blocks_per_sm, typename... EnclosedStmts>
+using CudaKernelFixedSM =
+    CudaKernelExt<cuda_explicit_launch<false,
+                                       operators::limits<int>::max(),
+                                       num_threads,
+                                       blocks_per_sm>,
                   EnclosedStmts...>;
 
 /*!
@@ -164,23 +177,26 @@ using CudaKernelFixedAsync =
  * number of threads (specified by num_threads) and min blocks per sm.
  * The kernel launch is asynchronous.
  */
-template <size_t num_threads, size_t blocks_per_sm, typename... EnclosedStmts>
+template<int num_threads, int blocks_per_sm, typename... EnclosedStmts>
 using CudaKernelFixedSMAsync =
-    CudaKernelExt<cuda_explicit_launch<true, operators::limits<size_t>::max(), num_threads, blocks_per_sm>,
+    CudaKernelExt<cuda_explicit_launch<true,
+                                       operators::limits<int>::max(),
+                                       num_threads,
+                                       blocks_per_sm>,
                   EnclosedStmts...>;
 
 /*!
  * A RAJA::kernel statement that launches a CUDA kernel with 1024 threads
  * The kernel launch is synchronous.
  */
-template <typename... EnclosedStmts>
+template<typename... EnclosedStmts>
 using CudaKernel = CudaKernelFixed<1024, EnclosedStmts...>;
 
 /*!
  * A RAJA::kernel statement that launches a CUDA kernel with 1024 threads
  * The kernel launch is asynchronous.
  */
-template <typename... EnclosedStmts>
+template<typename... EnclosedStmts>
 using CudaKernelAsync = CudaKernelFixedAsync<1024, EnclosedStmts...>;
 
 }  // namespace statement
@@ -192,17 +208,16 @@ namespace internal
 /*!
  * CUDA global function for launching CudaKernel policies
  */
-template <typename Data, typename Exec>
+template<typename Data, typename Exec>
 __global__ void CudaKernelLauncher(Data data)
 {
 
-  using data_t = camp::decay<Data>;
+  using data_t        = camp::decay<Data>;
   data_t private_data = data;
 
   Exec::exec(private_data, true);
 }
 
-
 /*!
  * CUDA global function for launching CudaKernel policies
  * This is annotated to guarantee that device code generated
@@ -210,19 +225,18 @@ __global__ void CudaKernelLauncher(Data data)
  *
  * This launcher is used by the CudaKerelFixed policies.
  */
-template <size_t BlockSize, size_t BlocksPerSM, typename Data, typename Exec>
+template<int BlockSize, int BlocksPerSM, typename Data, typename Exec>
 __launch_bounds__(BlockSize, BlocksPerSM) __global__
     void CudaKernelLauncherFixed(Data data)
 {
 
-  using data_t = camp::decay<Data>;
+  using data_t        = camp::decay<Data>;
   data_t private_data = data;
 
   // execute the the object
   Exec::exec(private_data, true);
 }
 
-
 /*!
  * Helper class that handles getting the correct global function for
  * CudaKernel policies. This class is specialized on whether or not BlockSize
@@ -231,13 +245,19 @@ __launch_bounds__(BlockSize, BlocksPerSM) __global__
  * The default case handles BlockSize != 0 and gets the fixed max block size
  * version of the kernel.
  */
-template<size_t BlockSize, size_t BlocksPerSM, typename Data, typename executor_t>
+template<int BlockSize, int BlocksPerSM, typename Data, typename executor_t>
 struct CudaKernelLauncherGetter
 {
-  using type = camp::decay<decltype(&internal::CudaKernelLauncherFixed<BlockSize, BlocksPerSM, Data, executor_t>)>;
+  using type =
+      camp::decay<decltype(&internal::CudaKernelLauncherFixed<BlockSize,
+                                                              BlocksPerSM,
+                                                              Data,
+                                                              executor_t>)>;
+
   static constexpr type get() noexcept
   {
-    return internal::CudaKernelLauncherFixed<BlockSize, BlocksPerSM, Data, executor_t>;
+    return &internal::CudaKernelLauncherFixed<BlockSize, BlocksPerSM, Data,
+                                              executor_t>;
   }
 };
 
@@ -248,56 +268,85 @@ struct CudaKernelLauncherGetter
 template<typename Data, typename executor_t>
 struct CudaKernelLauncherGetter<0, 0, Data, executor_t>
 {
-  using type = camp::decay<decltype(&internal::CudaKernelLauncher<Data, executor_t>)>;
+  using type =
+      camp::decay<decltype(&internal::CudaKernelLauncher<Data, executor_t>)>;
+
   static constexpr type get() noexcept
   {
-    return internal::CudaKernelLauncher<Data, executor_t>;
+    return &internal::CudaKernelLauncher<Data, executor_t>;
   }
 };
 
 
-
 /*!
  * Helper class that handles CUDA kernel launching, and computing
  * maximum number of threads/blocks
  */
-template<typename LaunchPolicy, typename StmtList, typename Data, typename Types>
+template<typename LaunchPolicy,
+         typename StmtList,
+         typename Data,
+         typename Types>
 struct CudaLaunchHelper;
 
-
 /*!
  * Helper class specialization to determine the number of threads and blocks.
  * The user may specify the number of threads and blocks or let one or both be
  * determined at runtime using the CUDA occupancy calculator.
  */
-template<bool async0, size_t num_blocks, size_t num_threads, size_t blocks_per_sm, typename StmtList, typename Data, typename Types>
-struct CudaLaunchHelper<cuda_launch<async0, num_blocks, num_threads, blocks_per_sm>,StmtList,Data,Types>
+template<bool async0,
+         int num_blocks,
+         int num_threads,
+         int blocks_per_sm,
+         typename StmtList,
+         typename Data,
+         typename Types>
+struct CudaLaunchHelper<
+    cuda_explicit_launch<async0, num_blocks, num_threads, blocks_per_sm>,
+    StmtList,
+    Data,
+    Types>
 {
   using Self = CudaLaunchHelper;
 
   static constexpr bool async = async0;
 
-  using executor_t = internal::cuda_statement_list_executor_t<StmtList, Data, Types>;
+  using executor_t =
+      internal::cuda_statement_list_executor_t<StmtList, Data, Types>;
 
-  using kernelGetter_t = CudaKernelLauncherGetter<(num_threads <= 0) ? 0 : num_threads, (blocks_per_sm <= 0) ? 0 : blocks_per_sm, Data, executor_t>;
+  using kernelGetter_t =
+      CudaKernelLauncherGetter<(num_threads <= 0) ? 0 : num_threads,
+                               (blocks_per_sm <= 0) ? 0 : blocks_per_sm,
+                               Data,
+                               executor_t>;
 
-  inline static void recommended_blocks_threads(int shmem_size,
-      size_t &recommended_blocks, size_t &recommended_threads)
+  inline static const void* get_func()
   {
-    auto func = kernelGetter_t::get();
+    return reinterpret_cast<const void*>(kernelGetter_t::get());
+  }
 
-    if (num_blocks <= 0) {
+  inline static void recommended_blocks_threads(size_t shmem_size,
+                                                int& recommended_blocks,
+                                                int& recommended_threads)
+  {
+    auto func = Self::get_func();
 
-      if (num_threads <= 0) {
+    if (num_blocks <= 0)
+    {
+
+      if (num_threads <= 0)
+      {
 
         //
         // determine blocks at runtime
         // determine threads at runtime
         //
-        internal::cuda_occupancy_max_blocks_threads<Self>(
-            func, shmem_size, recommended_blocks, recommended_threads);
-
-      } else {
+        auto data = ::RAJA::cuda::cuda_occupancy_max_blocks_threads<Self>(
+            func, shmem_size);
+        recommended_blocks  = data.func_max_blocks_per_device;
+        recommended_threads = data.func_max_threads_per_block;
+      }
+      else
+      {
 
         //
         // determine blocks at runtime
@@ -305,107 +354,104 @@ struct CudaLaunchHelper<cuda_launch<async0, num_blocks, num_threads, blocks_per_
         //
         recommended_threads = num_threads;
 
-        internal::cuda_occupancy_max_blocks<Self, num_threads>(
-            func, shmem_size, recommended_blocks);
-
+        auto data = ::RAJA::cuda::cuda_occupancy_max_blocks<Self, num_threads>(
+            func, shmem_size);
+        recommended_blocks =
+            data.func_max_blocks_per_sm * data.device_sm_per_device;
       }
+    }
+    else
+    {
 
-    } else {
-
-      if (num_threads <= 0) {
+      if (num_threads <= 0)
+      {
 
         //
         // determine threads at runtime, unsure what use 1024
         // this value may be invalid for kernels with high register pressure
         //
         recommended_threads = 1024;
-
-      } else {
+      }
+      else
+      {
 
         //
         // threads determined at compile-time
         //
         recommended_threads = num_threads;
-
       }
 
       //
       // blocks determined at compile-time
       //
       recommended_blocks = num_blocks;
-
     }
   }
 
-  inline static void max_threads(int RAJA_UNUSED_ARG(shmem_size), size_t &max_threads)
+  inline static void max_threads(size_t RAJA_UNUSED_ARG(shmem_size),
+                                 int& max_threads)
   {
-    if (num_threads <= 0) {
+    if (num_threads <= 0)
+    {
 
       //
       // determine threads at runtime, unsure what use 1024
       // this value may be invalid for kernels with high register pressure
       //
       max_threads = 1024;
-
-    } else {
+    }
+    else
+    {
 
       //
       // threads determined at compile-time
       //
       max_threads = num_threads;
-
     }
   }
 
-  inline static void max_blocks(int shmem_size,
-      size_t &max_blocks, size_t actual_threads)
+  inline static void max_blocks(size_t shmem_size,
+                                int& max_blocks,
+                                int actual_threads)
   {
-    auto func = kernelGetter_t::get();
+    auto func = Self::get_func();
 
-    if (num_blocks <= 0) {
+    if (num_blocks <= 0)
+    {
 
       //
       // determine blocks at runtime
       //
-      if (num_threads <= 0 ||
-          num_threads != actual_threads) {
+      if (num_threads <= 0 || num_threads != actual_threads)
+      {
 
         //
         // determine blocks when actual_threads != num_threads
         //
-        internal::cuda_occupancy_max_blocks<Self>(
-            func, shmem_size, max_blocks, actual_threads);
-
-      } else {
+        auto data = ::RAJA::cuda::cuda_occupancy_max_blocks<Self>(
+            func, shmem_size, actual_threads);
+        max_blocks = data.func_max_blocks_per_sm * data.device_sm_per_device;
+      }
+      else
+      {
 
         //
         // determine blocks when actual_threads == num_threads
         //
-        internal::cuda_occupancy_max_blocks<Self, num_threads>(
-            func, shmem_size, max_blocks);
-
+        auto data = ::RAJA::cuda::cuda_occupancy_max_blocks<Self, num_threads>(
+            func, shmem_size);
+        max_blocks = data.func_max_blocks_per_sm * data.device_sm_per_device;
       }
-
-    } else {
+    }
+    else
+    {
 
       //
       // blocks determined at compile-time
       //
       max_blocks = num_blocks;
-
     }
   }
-
-  static void launch(Data &&data,
-                     internal::LaunchDims launch_dims,
-                     size_t shmem,
-                     RAJA::resources::Cuda res)
-  {
-    auto func = kernelGetter_t::get();
-
-    void *args[] = {(void*)&data};
-    RAJA::cuda::launch((const void*)func, launch_dims.blocks, launch_dims.threads, args, shmem, res, async);
-  }
 };
 
 /*!
@@ -417,8 +463,10 @@ struct CudaLaunchHelper<cuda_launch<async0, num_blocks, num_threads, blocks_per_
  * The algorithm is greedy (and probably could be improved), and favors
  * maximizing the number of threads (or blocks) in x, y, then z.
  */
-inline
-cuda_dim_t fitCudaDims(size_t limit, cuda_dim_t result, cuda_dim_t minimum = cuda_dim_t()){
+inline cuda_dim_t fitCudaDims(cuda_dim_member_t limit,
+                              cuda_dim_t result,
+                              cuda_dim_t minimum = cuda_dim_t())
+{
 
 
   // clamp things to at least 1
@@ -431,12 +479,13 @@ cuda_dim_t fitCudaDims(size_t limit, cuda_dim_t result, cuda_dim_t minimum = cud
   minimum.z = minimum.z ? minimum.z : 1;
 
   // if we are under the limit, we're done
-  if(result.x * result.y * result.z <= limit) return result;
+  if (result.x * result.y * result.z <= limit) return result;
 
   // Can we reduce z to fit?
-  if(result.x * result.y * minimum.z < limit){
+  if (result.x * result.y * minimum.z < limit)
+  {
     // compute a new z
-    result.z = limit / (result.x*result.y);
+    result.z = limit / (result.x * result.y);
     return result;
   }
   // we don't fit, so reduce z to it's minimum and continue on to y
@@ -444,9 +493,10 @@ cuda_dim_t fitCudaDims(size_t limit, cuda_dim_t result, cuda_dim_t minimum = cud
 
 
   // Can we reduce y to fit?
-  if(result.x * minimum.y * result.z < limit){
+  if (result.x * minimum.y * result.z < limit)
+  {
     // compute a new y
-    result.y = limit / (result.x*result.z);
+    result.y = limit / (result.x * result.z);
     return result;
   }
   // we don't fit, so reduce y to it's minimum and continue on to x
@@ -454,9 +504,10 @@ cuda_dim_t fitCudaDims(size_t limit, cuda_dim_t result, cuda_dim_t minimum = cud
 
 
   // Can we reduce y to fit?
-  if(minimum.x * result.y * result.z < limit){
+  if (minimum.x * result.y * result.z < limit)
+  {
     // compute a new x
-    result.x = limit / (result.y*result.z);
+    result.x = limit / (result.y * result.z);
     return result;
   }
   // we don't fit, so we'll return the smallest possible thing
@@ -465,24 +516,26 @@ cuda_dim_t fitCudaDims(size_t limit, cuda_dim_t result, cuda_dim_t minimum = cud
   return result;
 }
 
-
 /*!
  * Specialization that launches CUDA kernels for RAJA::kernel from host code
  */
-template <typename LaunchConfig, typename... EnclosedStmts, typename Types>
+template<typename LaunchConfig, typename... EnclosedStmts, typename Types>
 struct StatementExecutor<
-    statement::CudaKernelExt<LaunchConfig, EnclosedStmts...>, Types> {
+    statement::CudaKernelExt<LaunchConfig, EnclosedStmts...>,
+    Types>
+{
 
   using stmt_list_t = StatementList<EnclosedStmts...>;
   using StatementType =
       statement::CudaKernelExt<LaunchConfig, EnclosedStmts...>;
 
-  template <typename Data>
-  static inline void exec(Data &&data)
+  template<typename Data>
+  static inline void exec(Data&& data)
   {
 
     using data_t = camp::decay<Data>;
-    using executor_t = cuda_statement_list_executor_t<stmt_list_t, data_t, Types>;
+    using executor_t =
+        cuda_statement_list_executor_t<stmt_list_t, data_t, Types>;
     using launch_t = CudaLaunchHelper<LaunchConfig, stmt_list_t, data_t, Types>;
 
 
@@ -496,84 +549,90 @@ struct StatementExecutor<
 
 
     // Only launch kernel if we have something to iterate over
-    size_t num_blocks = launch_dims.num_blocks();
-    size_t num_threads = launch_dims.num_threads();
-    if (num_blocks > 0 || num_threads > 0) {
+    bool active_threads = launch_dims.threads_are_active();
+    bool active_blocks  = launch_dims.blocks_are_active();
+    int num_blocks      = launch_dims.num_blocks();
+    int num_threads     = launch_dims.num_threads();
+    if ((active_threads || active_blocks) &&
+        (!active_blocks || num_blocks > 0) &&
+        (!active_threads || num_threads > 0))
+    {
 
       //
       // Setup shared memory buffers
       //
-      int shmem = 0;
+      size_t shmem = 0;
 
 
       //
       // Compute the recommended physical kernel blocks and threads
       //
-      size_t recommended_blocks;
-      size_t recommended_threads;
-      launch_t::recommended_blocks_threads(
-          shmem, recommended_blocks, recommended_threads);
+      int recommended_blocks;
+      int recommended_threads;
+      launch_t::recommended_blocks_threads(shmem, recommended_blocks,
+                                           recommended_threads);
 
 
       //
       // Compute the MAX physical kernel threads
       //
-      size_t max_threads;
+      int max_threads;
       launch_t::max_threads(shmem, max_threads);
 
 
       //
       // Fit the requested threads
       //
-      cuda_dim_t fit_threads{0,0,0};
+      cuda_dim_t fit_threads {0, 0, 0};
 
-      if ( recommended_threads >= get_size(launch_dims.min_threads) ) {
-
-        fit_threads = fitCudaDims(
-            recommended_threads, launch_dims.threads, launch_dims.min_threads);
+      if (recommended_threads >= get_size(launch_dims.min_dims.threads))
+      {
 
+        fit_threads = fitCudaDims(recommended_threads, launch_dims.dims.threads,
+                                  launch_dims.min_dims.threads);
       }
 
       //
       // Redo fit with max threads
       //
-      if ( recommended_threads < max_threads &&
-           get_size(fit_threads) != recommended_threads ) {
-
-        fit_threads = fitCudaDims(
-            max_threads, launch_dims.threads, launch_dims.min_threads);
+      if (recommended_threads < max_threads &&
+          get_size(fit_threads) != recommended_threads)
+      {
 
+        fit_threads = fitCudaDims(max_threads, launch_dims.dims.threads,
+                                  launch_dims.min_dims.threads);
       }
 
-      launch_dims.threads = fit_threads;
+      launch_dims.dims.threads = fit_threads;
 
 
       //
       // Compute the MAX physical kernel blocks
       //
-      size_t max_blocks;
+      int max_blocks;
       launch_t::max_blocks(shmem, max_blocks, launch_dims.num_threads());
 
-      size_t use_blocks;
+      int use_blocks;
 
-      if ( launch_dims.num_threads() == recommended_threads ) {
+      if (launch_dims.num_threads() == recommended_threads)
+      {
 
         //
         // Fit the requested blocks
         //
         use_blocks = recommended_blocks;
-
-      } else {
+      }
+      else
+      {
 
         //
         // Fit the max blocks
         //
         use_blocks = max_blocks;
-
       }
 
-      launch_dims.blocks = fitCudaDims(
-          use_blocks, launch_dims.blocks, launch_dims.min_blocks);
+      launch_dims.dims.blocks = fitCudaDims(use_blocks, launch_dims.dims.blocks,
+                                            launch_dims.min_dims.blocks);
 
       //
       // make sure that we fit
@@ -582,22 +641,32 @@ struct StatementExecutor<
       if(launch_dims.num_blocks() > max_blocks){
         RAJA_ABORT_OR_THROW("RAJA::kernel exceeds max num blocks");
       }*/
-      if(launch_dims.num_threads() > max_threads){
+      if (launch_dims.num_threads() > max_threads)
+      {
         RAJA_ABORT_OR_THROW("RAJA::kernel exceeds max num threads");
       }
 
       {
+        auto func = launch_t::get_func();
+
         //
         // Privatize the LoopData, using make_launch_body to setup reductions
         //
+        // Note that there is a circular dependency between the previous setup
+        // of the launch_dims and potential changes to shmem here that is
+        // currently an unresolved issue.
+        //
         auto cuda_data = RAJA::cuda::make_launch_body(
-            launch_dims.blocks, launch_dims.threads, shmem, res, data);
-
+            func, launch_dims.dims.blocks, launch_dims.dims.threads, shmem, res,
+            data);
 
         //
-        // Launch the kernels
+        // Launch the kernel
         //
-        launch_t::launch(std::move(cuda_data), launch_dims, shmem, res);
+        void* args[] = {(void*)&cuda_data};
+        RAJA::cuda::launch(func, launch_dims.dims.blocks,
+                           launch_dims.dims.threads, args, shmem, res,
+                           launch_t::async);
       }
     }
   }
