@@ -3,14 +3,14 @@
  *
  * \file
  *
- * \brief   Header file containing RAJA Vtable and WorkRunner constructs.
+ * \brief   Header file containing RAJA Dispatcher and WorkRunner constructs.
  *
  ******************************************************************************
  */
 
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
-// Copyright (c) 2016-21, Lawrence Livermore National Security, LLC
-// and RAJA project contributors. See the RAJA/COPYRIGHT file for details.
+// Copyright (c) 2016-25, Lawrence Livermore National Security, LLC
+// and RAJA project contributors. See the RAJA/LICENSE file for details.
 //
 // SPDX-License-Identifier: (BSD-3-Clause)
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
@@ -18,7 +18,7 @@
 #ifndef RAJA_sequential_WorkGroup_HPP
 #define RAJA_sequential_WorkGroup_HPP
 
-#include "RAJA/policy/sequential/WorkGroup/Vtable.hpp"
+#include "RAJA/policy/sequential/WorkGroup/Dispatcher.hpp"
 #include "RAJA/policy/sequential/WorkGroup/WorkRunner.hpp"
 
 #endif  // closing endif for header file include guard
