@@ -13,8 +13,8 @@
  */
 
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
-// Copyright (c) 2016-21, Lawrence Livermore National Security, LLC
-// and RAJA project contributors. See the RAJA/COPYRIGHT file for details.
+// Copyright (c) 2016-25, Lawrence Livermore National Security, LLC
+// and RAJA project contributors. See the RAJA/LICENSE file for details.
 //
 // SPDX-License-Identifier: (BSD-3-Clause)
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
@@ -26,6 +26,7 @@
 
 #include "RAJA/util/macros.hpp"
 
+#include <string.h>
 
 namespace RAJA
 {
@@ -36,18 +37,14 @@ namespace util
 /*!
  * Reinterpret any datatype as another datatype of the same size
  */
-template <typename A, typename B>
-RAJA_INLINE RAJA_HOST_DEVICE constexpr B reinterp_A_as_B(A const &val)
+template<typename A, typename B>
+RAJA_INLINE RAJA_HOST_DEVICE constexpr B reinterp_A_as_B(A const& a)
 {
-  static_assert(sizeof(A) == sizeof(B), "A and B must be same size");
-  return reinterpret_cast<B const &>(val);
-}
+  static_assert(sizeof(A) == sizeof(B), "A and B must be the same size");
 
-template <typename A, typename B>
-RAJA_INLINE RAJA_HOST_DEVICE constexpr B reinterp_A_as_B(A volatile const &val)
-{
-  static_assert(sizeof(A) == sizeof(B), "A and B must be same size");
-  return reinterpret_cast<B const volatile &>(val);
+  B b;
+  memcpy(&b, &a, sizeof(A));
+  return b;
 }
 
 
