@@ -11,8 +11,8 @@
  */
 
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
-// Copyright (c) 2016-21, Lawrence Livermore National Security, LLC
-// and RAJA project contributors. See the RAJA/COPYRIGHT file for details.
+// Copyright (c) 2016-25, Lawrence Livermore National Security, LLC
+// and RAJA project contributors. See the RAJA/LICENSE file for details.
 //
 // SPDX-License-Identifier: (BSD-3-Clause)
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
@@ -32,19 +32,19 @@ namespace concepts
 {
 using namespace camp::concepts;
 
-template <typename From, typename To>
+template<typename From, typename To>
 struct ConvertibleTo
-  : DefineConcept(::RAJA::concepts::convertible_to<To>(camp::val<From>())) {
-};
+    : DefineConcept(::RAJA::concepts::convertible_to<To>(camp::val<From>()))
+{};
 
-}
+}  // namespace concepts
 
 namespace type_traits
 {
 using namespace camp::type_traits;
 
 DefineTypeTraitFromConcept(convertible_to, concepts::ConvertibleTo);
-}
+}  // namespace type_traits
 
 }  // end namespace RAJA
 
