@@ -30,9 +30,9 @@ cmake \
   -C ${RAJA_HOSTCONFIG} \
   -DENABLE_OPENMP=Off \
   -DENABLE_CUDA=Off \
-  -DENABLE_TARGET_OPENMP=Off \
+  -DRAJA_ENABLE_TARGET_OPENMP=Off \
   -DENABLE_ALL_WARNINGS=Off \
-  -DENABLE_SYCL=On \
+  -DRAJA_ENABLE_SYCL=On \
   -DCMAKE_LINKER=clang++ \
   -DCMAKE_CXX_STANDARD=17 \
   -DENABLE_TESTS=Off \
