@@ -30,12 +30,13 @@ cmake \
   -C ${RAJA_HOSTCONFIG} \
   -DENABLE_OPENMP=Off \
   -DENABLE_CUDA=Off \
-  -DENABLE_TARGET_OPENMP=Off \
+  -DRAJA_ENABLE_TARGET_OPENMP=Off \
   -DENABLE_ALL_WARNINGS=Off \
-  -DENABLE_SYCL=On \
+  -DRAJA_ENABLE_SYCL=On \
   -DCMAKE_LINKER=clang++ \
   -DCMAKE_CXX_STANDARD=17 \
-  -DENABLE_TESTS=Off \
+  -DBLT_CXX_STD=c++17 \
+  -DENABLE_TESTS=On \
   -DENABLE_EXAMPLES=On \
   "$@" \
   ..
