@@ -1,12 +1,12 @@
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
-// Copyright (c) 2016-21, Lawrence Livermore National Security, LLC
-// and RAJA project contributors. See the RAJA/COPYRIGHT file for details.
+// Copyright (c) 2016-25, Lawrence Livermore National Security, LLC
+// and RAJA project contributors. See the RAJA/LICENSE file for details.
 //
 // SPDX-License-Identifier: (BSD-3-Clause)
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
 
 //
-// Types and type lists for loop indexing used throughout RAJA tests.
+// Type list for testing RAJA atomics.
 //
 // Note that in the type lists, a subset of types is used by default.
 // For more comprehensive type testing define the macro RAJA_TEST_EXHAUSTIVE.
@@ -25,7 +25,7 @@ using AtomicDataTypeList =
   camp::list< RAJA::Index_type,
               int,
 #if defined(RAJA_TEST_EXHAUSTIVE)
-              unsigned,
+              unsigned int,
               long long,
               unsigned long long,
               float,
