@@ -1,6 +1,6 @@
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
-// Copyright (c) 2016-21, Lawrence Livermore National Security, LLC
-// and RAJA project contributors. See the RAJA/COPYRIGHT file for details.
+// Copyright (c) 2016-25, Lawrence Livermore National Security, LLC
+// and RAJA project contributors. See the RAJA/LICENSE file for details.
 //
 // SPDX-License-Identifier: (BSD-3-Clause)
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
@@ -26,10 +26,6 @@ using SequentialResourceList = HostResourceList;
 using OpenMPResourceList = HostResourceList;
 #endif
 
-#if defined(RAJA_ENABLE_TBB)
-using TBBResourceList = HostResourceList;
-#endif
-
 #if defined(RAJA_ENABLE_CUDA)
 using CudaResourceList = camp::list<camp::resources::Cuda>;
 #endif
@@ -42,4 +38,8 @@ using OpenMPTargetResourceList = camp::list<camp::resources::Omp>;
 using HipResourceList = camp::list<camp::resources::Hip>;
 #endif
 
+#if defined(RAJA_ENABLE_SYCL)
+using SyclResourceList = camp::list<camp::resources::Sycl>;
+#endif
+
 #endif // __RAJA_test_camp_HPP__
