@@ -1,6 +1,6 @@
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
-// Copyright (c) 2016-21, Lawrence Livermore National Security, LLC
-// and RAJA project contributors. See the RAJA/COPYRIGHT file for details.
+// Copyright (c) 2016-25, Lawrence Livermore National Security, LLC
+// and RAJA project contributors. See the RAJA/LICENSE file for details.
 //
 // SPDX-License-Identifier: (BSD-3-Clause)
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
@@ -33,10 +33,6 @@ using SequentialPlatformList = HostPlatformList;
 using OpenMPPlatformList = HostPlatformList;
 #endif
 
-#if defined(RAJA_ENABLE_TBB)
-using TBBPlatformList = HostPlatformList;
-#endif
-
 #if defined(RAJA_ENABLE_CUDA)
 using CudaPlatformList = camp::list<PlatformHolder<RAJA::Platform::cuda>>;
 #endif
