@@ -1,6 +1,6 @@
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
-// Copyright (c) 2016-21, Lawrence Livermore National Security, LLC
-// and RAJA project contributors. See the RAJA/COPYRIGHT file for details.
+// Copyright (c) 2016-25, Lawrence Livermore National Security, LLC
+// and RAJA project contributors. See the RAJA/LICENSE file for details.
 //
 // SPDX-License-Identifier: (BSD-3-Clause)
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
@@ -22,7 +22,7 @@ GPU_TEST(SynchronizeTest, CUDA)
   });
   RAJA::synchronize<RAJA::cuda_synchronize>();
 
-  RAJA::forall<RAJA::loop_exec>( RAJA::RangeSegment(0, 50),
+  RAJA::forall<RAJA::seq_exec>( RAJA::RangeSegment(0, 50),
     [=](RAJA::Index_type i) {
     EXPECT_EQ(managed_data[i], 1.0 * i);
   });
