@@ -1,6 +1,6 @@
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
-// Copyright (c) 2016-21, Lawrence Livermore National Security, LLC
-// and RAJA project contributors. See the RAJA/COPYRIGHT file for details.
+// Copyright (c) 2016-25, Lawrence Livermore National Security, LLC
+// and RAJA project contributors. See the RAJA/LICENSE file for details.
 //
 // SPDX-License-Identifier: (BSD-3-Clause)
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
@@ -12,11 +12,20 @@
 #include "tests/test-reducer-constructors.hpp"
 
 #if defined(RAJA_ENABLE_HIP)
+using HipBasicReducerConstructorTypes = 
+  Test< camp::cartesian_product< HipReducerPolicyList,
+                                 DataTypeList,
+                                 HipResourceList > >::Types;
+
 using HipInitReducerConstructorTypes = 
   Test< camp::cartesian_product< HipReducerPolicyList,
                                  DataTypeList,
                                  HipResourceList,
-                                 HipForoneList > >::Types;
+                                 HipUnitTestPolicyList > >::Types;
+
+INSTANTIATE_TYPED_TEST_SUITE_P(HipBasicTest,
+                               ReducerBasicConstructorUnitTest,
+                               HipBasicReducerConstructorTypes);
 
 INSTANTIATE_TYPED_TEST_SUITE_P(HipInitTest,
                                ReducerInitConstructorUnitTest,
