@@ -1,6 +1,6 @@
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
-// Copyright (c) 2016-21, Lawrence Livermore National Security, LLC
-// and RAJA project contributors. See the RAJA/COPYRIGHT file for details.
+// Copyright (c) 2016-25, Lawrence Livermore National Security, LLC
+// and RAJA project contributors. See the RAJA/LICENSE file for details.
 //
 // SPDX-License-Identifier: (BSD-3-Clause)
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
@@ -21,7 +21,7 @@ using OpenMPInitReducerConstructorTypes =
   Test< camp::cartesian_product< OpenMPReducerPolicyList,
                                  DataTypeList,
                                  HostResourceList,
-                                 SequentialForoneList > >::Types;
+                                 SequentialUnitTestPolicyList > >::Types;
 
 INSTANTIATE_TYPED_TEST_SUITE_P(OpenMPBasicTest,
                                ReducerBasicConstructorUnitTest,
