@@ -1,6 +1,6 @@
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
-// Copyright (c) 2016-21, Lawrence Livermore National Security, LLC
-// and RAJA project contributors. See the RAJA/COPYRIGHT file for details.
+// Copyright (c) 2016-25, Lawrence Livermore National Security, LLC
+// and RAJA project contributors. See the RAJA/LICENSE file for details.
 //
 // SPDX-License-Identifier: (BSD-3-Clause)
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
@@ -22,10 +22,6 @@ using DataTypeList = camp::list< int,
 
 using SequentialReducerPolicyList = camp::list< RAJA::seq_reduce >;
 
-#if defined(RAJA_ENABLE_TBB)
-using TBBReducerPolicyList = camp::list< RAJA::tbb_reduce >;
-#endif
-
 #if defined(RAJA_ENABLE_OPENMP)
 using OpenMPReducerPolicyList = camp::list< RAJA::omp_reduce,
                                             RAJA::omp_reduce_ordered >;
